@@ -24,16 +24,22 @@ def preprocessing(func):
 
 
 async def error_log_middleware(request, handler):
-    Logger.log_request(method=request.method,
-                       url=str(request.url),
-                       user_agent=request.headers["User-Agent"],
-                       referrer=request.headers["Referrer"],  # TODO check how it work
-                       response_status_code=0,
-                       remote_ip=request.remote)
+    try:
+        Logger.log_request(method=request.method,
+                           url=str(request.url),
+                           user_agent=request.headers.get("User-Agent", "-"),
+                           referrer=request.headers.get("Referrer", "-"),  # TODO check how it work
+                           response_status_code=0,
+                           remote_ip=request.remote)
+    except Exception as e:
+        Logger().info("Can't log request", {"request": str(request), "exception": e})
     response = await handler(request)
-    Logger.set_log_request_response_status_code(response.status)
-    if response.status >= 400:
-        Logger().error("Http request error")
+    try:
+        Logger.set_log_request_response_status_code(response.status)
+        if response.status >= 400:
+            Logger().error("Http request error")
+    except Exception as e:
+        Logger().info("Can't log request", {"request": str(request), "exception": e, "response": str(response)})
     return response
 
 # Нужно для работы в aiohttp (см. реализацию декоратор middleware в aiohttp)
